==> v8.3.zip: ru_twords_ru_tw/bible/names/obadiah.md <==
# Авдий(во всех ссылках Овадий, кроме пр. Авдия 1)

## Факты:

Авдий — ветхозаветный пророк, который пророчествовал против жителей Едома — потомков Исава. В Ветхом Завете упоминаются многие люди по имени Авдий.

* Книга Авдия — самая короткая в Ветхом Завете. И в ней записано пророчество, полученное Авдием в видении от Бога.
* Точно не известно, когда жил и пророчествовал Авдий. Возможно, он жил в Иудее во время царствования Иорама, Охозии, Иоаса и Гофолии, а также во времена пророков Даниила, Иезекииля и Иеремии.
* Авдий мог жить и в более поздний период, во время царствования Седекии и вавилонского плена.
* Среди других людей носивших имя Авдий были: потомок Саула, один из людей Давида из колена Гада, управитель дворца царя Ахава, чиновник царя Иосафата, левит, служивший привратником в период Неемии, а также человек, который помогал ремонтировать храм во время правления царя Иосии.
* Не исключено, что один из этих людей был автором книги Авдия.

(Варианты перевода: [Как переводить имена](rc://*/ta/man/translate/translate-names))

(См. также: [Ахав](../names/ahab.md), [Вавилон, вавилонский](../names/babylon.md), [Давид](../names/david.md), [Едом, едомляне, Идумея, Сеир, Теман](../names/edom.md), [Исав](../names/esau.md), [Иезекииль](../names/ezekiel.md), [Даниил](../names/daniel.md), [Гад](../names/gad.md), [Иосафат](../names/jehoshaphat.md), [Иосия](../names/josiah.md), [Левит, Левий](../names/levite.md), [Саул (ВЗ)](../names/saul.md), [Седекия](../names/zedekiah.md))

## Ссылки на библейский текст:

* [1 Пар. 3:19-21](rc://*/tn/help/1ch/03/19)
* [1 Пар. 8:38-40](rc://*/tn/help/1ch/08/38)
* [Ezra 8:8-11](rc://*/tn/help/ezr/08/08)
* [Obadiah 1:1-2](rc://*/tn/help/oba/01/01)

## Данные о слове:

* Номера Стронга: H5662

==> v9.2.zip: ru_twords_ru_tw/bible/names/obadiah.md <==
# Авдий(во всех ссылках Овадий, кроме пр. Авдия 1)

## Факты:

Авдий — ветхозаветный пророк, который пророчествовал против жителей Едома — потомков Исава. В Ветхом Завете упоминаются многие люди по имени Авдий.

* Книга Авдия — самая короткая в Ветхом Завете. И в ней записано пророчество, полученное Авдием в видении от Бога.
* Точно не известно, когда жил и пророчествовал Авдий. Возможно, он жил в Иудее во время царствования Иорама, Охозии, Иоаса и Гофолии, а также во времена пророков Даниила, Иезекииля и Иеремии.
* Авдий мог жить и в более поздний период, во время царствования Седекии и вавилонского плена.
* Среди других людей носивших имя Авдий были: потомок Саула, один из людей Давида из колена Гада, управитель дворца царя Ахава, чиновник царя Иосафата, левит, служивший привратником в период Неемии, а также человек, который помогал ремонтировать храм во время правления царя Иосии.
* Не исключено, что один из этих людей был автором книги Авдия.

(Варианты перевода: [Как переводить имена](rc://ru/ta/man/translate/translate-names))

(См. также: [Ахав](../names/ahab.md), [Вавилон, вавилонский](../names/babylon.md), [Давид](../names/david.md), [Едом, едомляне, Идумея, Сеир, Теман](../names/edom.md), [Исав](../names/esau.md), [Иезекииль](../names/ezekiel.md), [Даниил](../names/daniel.md), [Гад](../names/gad.md), [Иосафат](../names/jehoshaphat.md), [Иосия](../names/josiah.md), [Левит, Левий](../names/levite.md), [Саул (ВЗ)](../names/saul.md), [Седекия](../names/zedekiah.md))

## Ссылки на библейский текст:

* [1 Пар. 3:19-21](rc://ru/tn/help/1ch/03/19)
* [1 Пар. 8:38-40](rc://ru/tn/help/1ch/08/38)
* [Ezra 8:8-11](rc://ru/tn/help/ezr/08/08)
* [Obadiah 1:1-2](rc://ru/tn/help/oba/01/01)

## Данные о слове:

* Номера Стронга: H5662
